MethodChannelHeicNative class

Implementation of HeicNativePlatform that uses a MethodChannel.

Inheritance

Constructors

MethodChannelHeicNative()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to communicate with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(String inputPath, String outputPath, {int compressionLevel = 6, bool preserveMetadata = true}) Future<bool>
Converts a HEIC/HEIF file at inputPath to PNG at outputPath.
override
convertToBytes(String inputPath, {int compressionLevel = 6, bool preserveMetadata = true}) Future<Uint8List>
Converts a HEIC/HEIF file at inputPath to PNG bytes in memory.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited