HeicNativePlatform class abstract
The interface that platform-specific implementations of heic_native must extend.
- Inheritance
-
- Object
- PlatformInterface
- HeicNativePlatform
- Implementers
Constructors
- HeicNativePlatform()
- Creates a new HeicNativePlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convert(
String inputPath, String outputPath, {int compressionLevel = 6, bool preserveMetadata = true}) → Future< bool> -
Converts a HEIC/HEIF file at
inputPathto PNG atoutputPath. -
convertToBytes(
String inputPath, {int compressionLevel = 6, bool preserveMetadata = true}) → Future< Uint8List> -
Converts a HEIC/HEIF file at
inputPathto PNG bytes in memory. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ HeicNativePlatform
-
The current platform-specific implementation of HeicNativePlatform.
getter/setter pair